@@ -6,13 +6,15 @@ use serde::{Deserialize, Serialize};
 #[derive(Debug, Clone, Copy, PartialEq, Eq, Serialize, Deserialize)]
 #[serde(rename_all = "lowercase")]
 pub enum ThemeVariant {
+    Default,
     Framework,
     Alucard,
-    Dracula,
     CatppuccinFrappe,
     CatppuccinLatte,
     CatppuccinMacchiato,
     CatppuccinMocha,
+    Dracula,
+    GameBoy,
     GithubDark,
     GithubLight,
     GruvboxDark,
@@ -27,13 +29,15 @@ impl FromStr for ThemeVariant {
 
     fn from_str(s: &str) -> Result<Self, Self::Err> {
         match s.to_lowercase().as_str() {
+            "default" => Ok(ThemeVariant::Default),
             "framework" => Ok(ThemeVariant::Framework),
             "alucard" => Ok(ThemeVariant::Alucard),
-            "dracula" => Ok(ThemeVariant::Dracula),
             "catppuccin_frappe" => Ok(ThemeVariant::CatppuccinFrappe),
             "catppuccin_latte" => Ok(ThemeVariant::CatppuccinLatte),
             "catppuccin_macchiato" => Ok(ThemeVariant::CatppuccinMacchiato),
             "catppuccin_mocha" => Ok(ThemeVariant::CatppuccinMocha),
+            "dracula" => Ok(ThemeVariant::Dracula),
+            "gameboy" => Ok(ThemeVariant::GameBoy),
             "github_dark" => Ok(ThemeVariant::GithubDark),
             "github_light" => Ok(ThemeVariant::GithubLight),
             "gruvbox_dark" => Ok(ThemeVariant::GruvboxDark),
@@ -49,13 +53,15 @@ impl FromStr for ThemeVariant {
 impl ThemeVariant {
     pub fn name(&self) -> &'static str {
         match self {
+            ThemeVariant::Default => "Default",
             ThemeVariant::Framework => "Framework",
             ThemeVariant::Alucard => "Alucard",
-            ThemeVariant::Dracula => "Dracula",
             ThemeVariant::CatppuccinFrappe => "Catppuccin Frappe",
             ThemeVariant::CatppuccinLatte => "Catppuccin Latte",
             ThemeVariant::CatppuccinMacchiato => "Catppuccin Macchiato",
             ThemeVariant::CatppuccinMocha => "Catppuccin Mocha",
+            ThemeVariant::Dracula => "Dracula",
+            ThemeVariant::GameBoy => "Game Boy",
             ThemeVariant::GithubDark => "GitHub Dark",
             ThemeVariant::GithubLight => "GitHub Light",
             ThemeVariant::GruvboxDark => "Gruvbox Dark",
@@ -66,14 +72,16 @@ impl ThemeVariant {
         }
     }
 
-    pub const ALL: [ThemeVariant; 14] = [
+    pub const ALL: [ThemeVariant; 16] = [
+        ThemeVariant::Default,
         ThemeVariant::Framework,
         ThemeVariant::Alucard,
-        ThemeVariant::Dracula,
         ThemeVariant::CatppuccinFrappe,
         ThemeVariant::CatppuccinLatte,
         ThemeVariant::CatppuccinMacchiato,
         ThemeVariant::CatppuccinMocha,
+        ThemeVariant::Dracula,
+        ThemeVariant::GameBoy,
         ThemeVariant::GithubDark,
         ThemeVariant::GithubLight,
         ThemeVariant::GruvboxDark,
@@ -116,20 +124,22 @@ pub struct Theme {
 
 impl Default for Theme {
     fn default() -> Self {
-        Theme::from_variant(ThemeVariant::Framework)
+        Theme::from_variant(ThemeVariant::Default)
     }
 }
 
 impl Theme {
     pub fn from_variant(variant: ThemeVariant) -> Self {
         match variant {
+            ThemeVariant::Default => Self::default0(),
             ThemeVariant::Framework => Self::framework(),
             ThemeVariant::Alucard => Self::alucard(),
-            ThemeVariant::Dracula => Self::dracula(),
             ThemeVariant::CatppuccinFrappe => Self::catppuccin_frappe(),
             ThemeVariant::CatppuccinLatte => Self::catppuccin_latte(),
             ThemeVariant::CatppuccinMacchiato => Self::catppuccin_macchiato(),
             ThemeVariant::CatppuccinMocha => Self::catppuccin_mocha(),
+            ThemeVariant::Dracula => Self::dracula(),
+            ThemeVariant::GameBoy => Self::gameboy(),
             ThemeVariant::GithubDark => Self::github_dark(),
             ThemeVariant::GithubLight => Self::github_light(),
             ThemeVariant::GruvboxDark => Self::gruvbox_dark(),
@@ -140,6 +150,23 @@ impl Theme {
         }
     }
 
+    pub fn default0() -> Self {
+        Self {
+            variant: ThemeVariant::Default,
+            text: Color::Indexed(7),
+            background: Color::Indexed(0),
+            border: Color::Indexed(15),
+            border_active: Color::Indexed(3),
+            indication_ok: Color::Indexed(2),
+            indication_warning: Color::Indexed(1),
+            brightness_bar: Color::Indexed(4),
+            charge_bar: Color::Indexed(4),
+            bar_background: Color::Indexed(0),
+            highlighted_text: Color::Indexed(4),
+            informative_text: Color::Indexed(5),
+        }
+    }
+
     pub fn framework() -> Self {
         Self {
             variant: ThemeVariant::Framework,
@@ -174,23 +201,6 @@ impl Theme {
         }
     }
 
-    pub fn dracula() -> Self {
-        Self {
-            variant: ThemeVariant::Dracula,
-            text: Color::from_str("#F8F8F2").unwrap(),
-            background: Color::from_str("#282A36").unwrap(),
-            border: Color::from_str("#FFB86C").unwrap(),
-            border_active: Color::from_str("#FFB86C").unwrap(),
-            indication_ok: Color::from_str("#50FA7B").unwrap(),
-            indication_warning: Color::from_str("#FF5555").unwrap(),
-            brightness_bar: Color::from_str("#F1FA8C").unwrap(),
-            charge_bar: Color::from_str("#8BE9FD").unwrap(),
-            bar_background: Color::from_str("#44475A").unwrap(),
-            highlighted_text: Color::from_str("#8BE9FD").unwrap(),
-            informative_text: Color::from_str("#BD93F9").unwrap(),
-        }
-    }
-
     pub fn catppuccin_frappe() -> Self {
         Self {
             variant: ThemeVariant::CatppuccinFrappe,
@@ -259,6 +269,40 @@ impl Theme {
         }
     }
 
+    pub fn dracula() -> Self {
+        Self {
+            variant: ThemeVariant::Dracula,
+            text: Color::from_str("#F8F8F2").unwrap(),
+            background: Color::from_str("#282A36").unwrap(),
+            border: Color::from_str("#FFB86C").unwrap(),
+            border_active: Color::from_str("#FFB86C").unwrap(),
+            indication_ok: Color::from_str("#50FA7B").unwrap(),
+            indication_warning: Color::from_str("#FF5555").unwrap(),
+            brightness_bar: Color::from_str("#F1FA8C").unwrap(),
+            charge_bar: Color::from_str("#8BE9FD").unwrap(),
+            bar_background: Color::from_str("#44475A").unwrap(),
+            highlighted_text: Color::from_str("#8BE9FD").unwrap(),
+            informative_text: Color::from_str("#BD93F9").unwrap(),
+        }
+    }
+
+    pub fn gameboy() -> Self {
+        Self {
+            variant: ThemeVariant::GameBoy,
+            text: Color::from_str("#9A9E3F").unwrap(),
+            background: Color::from_str("#1B2A09").unwrap(),
+            border: Color::from_str("#496B22").unwrap(),
+            border_active: Color::from_str("#9A9E3F").unwrap(),
+            indication_ok: Color::from_str("#9A9E3F").unwrap(),
+            indication_warning: Color::from_str("#9A9E3F").unwrap(),
+            brightness_bar: Color::from_str("#9A9E3F").unwrap(),
+            charge_bar: Color::from_str("#9A9E3F").unwrap(),
+            bar_background: Color::from_str("#0E450B").unwrap(),
+            highlighted_text: Color::from_str("#9A9E3F").unwrap(),
+            informative_text: Color::from_str("#9A9E3F").unwrap(),
+        }
+    }
+
     pub fn github_dark() -> Self {
         Self {
             variant: ThemeVariant::GithubDark,
